/* ******************************************************************

   class    : AppletViewDlg
   date     : 20.08.98
   compiler : javac (jdk 1.1.6)

*********************************************************************/

package AppletView;

/* ******************************************************************
   import statements
*********************************************************************/

import java.applet.*;
import java.awt.*;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.awt.event.WindowListener;
import java.awt.event.WindowEvent;
import java.io.*;
import java.net.URL;
import java.net.MalformedURLException;
import java.util.ResourceBundle;

import CustCtrl.BaseDialog;
import CustCtrl.InsetsPanel;
import Utils.ResourceUtil;
import SysExt.FileClassLoader;

import com.sun.java.swing.JOptionPane;

/**
 * A dialog that displays an applet.
 *
 * @author puehringer edgar
 */
public class AppletViewDlg extends BaseDialog
  implements ActionListener,WindowListener {

  // class variable declarations
  private final static String TITLE       = "title";
  private final static String BUTTONS     = "buttons";
  private final static String INFO_TITLE  = "infoTitle";
  private final static String NO_APP_INFO = "noAppletInfo";
  private final static String NO_PAR_INFO = "noParamInfo";

  // instance variable declarations
  /** The parent frame of this dialog. */
  private Frame parent;
  private Applet applet;
  private AppletTag tag;
  private URL codeBase;
  private URL docBase;
  private AppletPanel panel;
  /** Contains some applet loading error messages. */
  private String message;
  private boolean firstStarted = false;
  private String infoTitle;
  private String noAppInfo;
  private String noParInfo;

  // constructors
  /** Create a new AppletViewDlg object. */
  public AppletViewDlg(Frame parent, ResourceBundle resources,
                    String resourcePrefix, File htmlFile) {
    super(parent,true);
    this.parent = parent;

    String str;

    addWindowListener(this);
    applet = getApplet(htmlFile);
    if (applet != null) panel = getAppletPanel(applet,tag,codeBase);
    if (message == null)
      getContentPanel().add(panel);
    else
      getContentPanel().add(new Label(message));
    // end if
    setTitle(ResourceUtil.getResStringOrKey(resources,
                    resourcePrefix + TITLE));
    createButtons(ResourceUtil.getResStringOrKey(resources,
                    resourcePrefix + BUTTONS));
    infoTitle = ResourceUtil.getResStringOrKey(resources,
                  resourcePrefix + INFO_TITLE);
    noAppInfo = ResourceUtil.getResStringOrKey(resources,
                  resourcePrefix + NO_APP_INFO);
    noParInfo = ResourceUtil.getResStringOrKey(resources,
                  resourcePrefix + NO_PAR_INFO);
    addActionListener(this);
    pack();
    center(parent);
    setResizable(false);
  } // end constructor AppletViewDlg

  // class methods
    /** Only for debuging purposes. */
  public static void main(String[] args) throws java.util.MissingResourceException {
    Frame frame = new Frame();
    AppletViewDlg dlg;
    ResourceBundle res;

    if (args.length < 2) {
      System.out.println("Resource file and html file must be specified.");
      System.exit(1);
    } // end if
    res = ResourceBundle.getBundle(args[0],java.util.Locale.getDefault());
    dlg = new AppletViewDlg(frame,res,"exec.appletViewDlg.",new File(args[1]));
    dlg.show();
    System.out.println("isCanceled returned " + dlg.isCanceled());
    System.exit(0);
  } // end main

  // methods
  /** Returns zero if the applet was executed successfully. */
  public int getExitValue() {
    return message == null ? 0 : 1;
  } // end getExitValue

  /** Returns the applet specified in htmlFile. */
  protected Applet getApplet(File htmlFile) {
    FileInputStream fin = null;
    AppletTagParser parser;
    String str;

    // parse the html file
    try {
      fin = new FileInputStream(htmlFile);
    } catch (FileNotFoundException excep) {
      message = "File not found: " + htmlFile;
    }
    if (fin == null) return null;
    parser = new AppletTagParser(fin);
    try {
      tag = parser.parse();
      if (tag == null) message = htmlFile + " contains no applet tag.";
    } catch (IOException excep) {
      message = "Exception on parsing " + htmlFile + ", Line " +
                parser.lineno() + ": " + excep;
    } finally {
      try { fin.close(); } catch (IOException e){}
    }
    if (tag == null) return null;
    // build the document base
    str = htmlFile.getAbsolutePath();
    str = "file:" + str.replace(File.separatorChar,'/');
    try {
      docBase = new URL(str);
    } catch (MalformedURLException excep) {
      message = "Malformed DocumentBase URL: " + str;
    }
    if (docBase == null) return null;
    // build the code base
    if (tag.codebase == null) {
      str = (new File(htmlFile.getParent())).getAbsolutePath();
      str = "file:" + str.replace(File.separatorChar,'/');
      if (!str.endsWith("/")) str += "/";
      try {
        codeBase = new URL(str);
      } catch (MalformedURLException excep) {
        message = "Malformed CodeBase URL: " + str;
        excep.printStackTrace();
      }
    }
    else {
      File file = new File(tag.codebase);

      if (!file.isAbsolute())
        file = new File(htmlFile.getParent(),tag.codebase);
      // end if
      if (file.isDirectory()) {
        str = file.getAbsolutePath();
        str = "file:" + str.replace(file.separatorChar,'/');
        if (!str.endsWith("/")) str += "/";
      }
      else {
        str = tag.codebase;
      } // end if
      try {
        codeBase = new URL(str);
      } catch (MalformedURLException excep) {
        message = "Malformed CodeBase URL: " + str;
      }
    } // end if
    if (codeBase == null) return null;
    // load the applet class
    URL url                    = null;
    InputStream is             = null;
    ByteArrayOutputStream baos = new ByteArrayOutputStream();
    byte[] buff                = new byte[4096];
    int nch;
    FileClassLoader loader;
    Class clazz = null;

    str = codeBase + tag.code;
    try {
      url = new URL(str);
    } catch (MalformedURLException excep) {
      message = "Malformed Class URL: " + str;
    }
    if (url == null) return null;
    try {
      is = url.openStream();
    } catch (IOException excep) {
      message = "Exception on opening stream: " + excep;
    }
    if (is == null) return null;
    try {
      while ((nch = is.read(buff,0,buff.length)) != -1) {
        baos.write(buff,0,nch);
      } // end while
    } catch (IOException excep) {
      excep.printStackTrace();
    } finally {
      try { is.close(); } catch (IOException e) {}
    }
    buff   = baos.toByteArray();
    str    = ".class";
    if (tag.code.endsWith(str))
      str = tag.code.substring(0,tag.code.length() - str.length());
    else
      str = tag.code;
    // end if
    // create a class loader
    String path = codeBase.toString();

    if (path.startsWith("file:")) {
      path   = ResourceUtil.urlToFile(path);
      loader = new FileClassLoader(path);
    }
    else {
      loader = new FileClassLoader();
    } // end if
    try {
      clazz = loader.loadClass(str,buff,true);
    } catch (ClassNotFoundException excep) {
      message = "Class not found: " + tag.code;
    }
    if (clazz == null) return null;
    // create an instance of the applet class
    Applet a = null;

    try {
      a = (Applet)clazz.newInstance();
    } catch (InstantiationException excep) {
      excep.printStackTrace();
    } catch (IllegalAccessException excep) {
      excep.printStackTrace();
    }
    return a;
  } // end getApplet

  /** Returns the applet specified in htmlFile. */
  protected AppletPanel getAppletPanel(Applet app, AppletTag at,
                                       URL db) {
    AppletContext context = new StandaloneContext();
    AppletPanel ap;

    ap = new AppletPanel(app,context,db,at.params);
    ap.setPreferredSize(new Dimension(at.width,at.height));
    ap.doLayout();
    return ap;
  } // end getAppletPanel

  /**
   * Called to close this dialog.
   */
  protected void closeDialog(AWTEvent event) {
    if ((event instanceof WindowEvent) || !isCanceled()) {
      super.closeDialog(event);
    } // end if
  } // end closeDialog

  public void actionPerformed(ActionEvent e) {
    String cmd   = e.getActionCommand();
    String label;

    if (buttonVector.size() < 4) return;
    label = ((Button)buttonVector.elementAt(1)).getLabel();
    if (cmd.equals(label)) { // if it's the start button
      panel.start();
    }
    else {
      label = ((Button)buttonVector.elementAt(2)).getLabel();
      if (cmd.equals(label)) { // if it's the stop button
        panel.stop();
      }
      else {
      label = ((Button)buttonVector.elementAt(3)).getLabel();
        if (cmd.equals(label)) { // if it's the info button
          String str       = applet.getAppletInfo();
          String[][] aaStr = applet.getParameterInfo();
          String[] aStr;

          if (str == null) str = noAppInfo;
          str += "\n\n";
          if (aaStr == null) {
            str+= noParInfo;
          }
          else {
            for (int i=0; i<aaStr.length; i++) {
              aStr = aaStr[i];
              for (int j=0; j<aStr.length; j++) {
                str += aStr[j];
                str += j == aStr.length - 1 ? "\n" : " -- ";
              } // end for
            } // end for
          } // end if
          JOptionPane.showMessageDialog(parent,str,infoTitle,
            JOptionPane.INFORMATION_MESSAGE);
        } // end if
      } // end if
    } // end if
  } // end actionPerformed

  // --- WindowListener ----------------------------------------------
  /** Invoked when a window has been opened. */
  public void windowOpened(WindowEvent e) {
    if (panel != null) panel.init();
  } // end windowOpened

  /** Invoked when a window is in the process of being closed. */
  public void windowClosing(WindowEvent e) {
    // do nothing
  } // end windowClosing

  /** Invoked when a window has been closed. */
  public void windowClosed(WindowEvent e) {
    if (panel !=null) panel.destroy();
  } // end windowClosed

  /** Invoked when a window is iconified. */
  public void windowIconified(WindowEvent e) {
    // do nothing
  } // end windowIconified

  /** Invoked when a window is deiconified. */
  public void windowDeiconified(WindowEvent e) {
    // do nothing
  } // end windowDeiconified

  /** Invoked when a window is activated. */
  public void windowActivated(WindowEvent e) {
    if ((panel != null) && !firstStarted) {
      firstStarted = true;
      panel.start();
    } // end if
    // no nothing
  } // end windowActivated

  /** Invoked when a window is deactivated. */
  public void windowDeactivated(WindowEvent e) {
    // do nothing
  } // end windowDeactivated

} // end AppletViewDlg

/* ******************************************************************
   end of file
*********************************************************************/
