/* ******************************************************************

	 class		: AudioClipTable
	 date 		: 19.08.98
	 compiler : javac (jdk 1.1.6)

*********************************************************************/

package AppletView;

/* ******************************************************************
	 import statements
*********************************************************************/

import java.applet.*;
import java.net.URL;
import java.util.Observable;
import java.util.Hashtable;

/**
 * A class that holds a list of audio clips created from an applet.
 *
 * @author puehringer edgar
 */
public class AudioClipTable extends Observable {

	// instance variable declarations
	private Hashtable clips;

	// constructors
	/** Create a new AudioClipTable object. */
	public AudioClipTable() {
		clips = new Hashtable();
	} // end constructor AudioClipTable

	// methods
	/** Returns an instance of an audio clip. */
	public AudioClip getAudioClip(URL url) {
		return new SilentClip(url);
	} // end getAudioClip

	/** Returns true if the audio clip specified by url is playing. */
	public boolean isPlaying(URL url) {
		return clips.containsKey(url);
	} // end isPlaying

	/** Returns true if a audio clip is playing in a loop. */
	public boolean isRepeating(URL url) {
		Object obj = clips.get(url);

		if (obj == null) return false;
		return ((Boolean)obj).booleanValue();
	} // end isRepeating

	private void notifyObs(URL url) {
		setChanged();
		notifyObservers(url);
	} // end notifyObs

	// inner classes
	/** This class manages an audio clip, but doesn't play it really. */
	protected class SilentClip implements AudioClip {

		// instance variable declarations
		private URL url;

		//constructors
		public SilentClip(URL url) {
			this.url = url;
		} // end constructor SilentClip

		// methods
		// - AudioClip ---------------------------------------------------
		/** Starts playing this audio clip. */
		public void play() {
			Object obj			= clips.get(url);
			boolean looping = (obj == null) || ((Boolean)obj).booleanValue();

			if (!looping) return;
			clips.put(url,new Boolean(false));
			notifyObs(url);
		} // end play

		/** Starts playing this audio clip in a loop. */
		public void loop() {
			Object obj			= clips.get(url);
			boolean looping = (obj != null) && ((Boolean)obj).booleanValue();

			if (looping) return;
			clips.put(url,new Boolean(true));
			notifyObs(url);
		} // end loop

		/** Stops playing this audio clip. */
		public void stop() {
			if (clips.remove(url) == null) return;
			notifyObs(url);
		} // end stop

	} // end SilentClip

} // end AudioClipTable

/* ******************************************************************
	 end of file
*********************************************************************/
