/* ******************************************************************

	 class		: StandaloneContext
	 date 		: 18.08.98
	 compiler : javac (jdk 1.1.6)

*********************************************************************/

package AppletView;

/* ******************************************************************
	 import statements
*********************************************************************/

import java.applet.*;
import java.awt.*;
import java.io.OutputStream;
import java.io.PrintWriter;
import java.net.URL;
import java.util.Enumeration;
import java.util.NoSuchElementException;
import java.util.Observer;
import java.util.Observable;

/**
 * A applet context for executing applets embedded.
 *
 * @author puehringer edgar
 */
public class StandaloneContext extends Observable
	implements AppletContext,Enumeration,Observer {

	// class variable declarations

	// instance variable declarations
	/** A class that creates audio clips. */
	protected AudioClipTable clipTable;
	/** A stream to write some status informations. */
	protected PrintWriter writer;

	// constructors
	/** Create a new StandaloneContext object. */
	public StandaloneContext() {
		this(null);
	} // end StandaloneContext

	public StandaloneContext(OutputStream out) {
		if (out != null) writer = new PrintWriter(out);
		clipTable = new AudioClipTable();
		clipTable.addObserver(this);
	} // end constructor StandaloneContext

	// methods
	// --- AppletContext -----------------------------------------------
	/**
	 * Creates an audio clip.
	 *
	 * @param url An absolute URL giving the location of the audio clip.
	 * @return The audio clip at the specified URL.
	 */
	public AudioClip getAudioClip(URL url) {
		return clipTable.getAudioClip(url);
	} // end getAudioClip

	/**
	 * Returns an Image object that can then be painted on the screen.	The
	 * url argument that is passed as an argument must specify an absolute
	 * URL.
	 *
	 * @param url An absolute URL giving the location of the image.
	 * @return The image at the specified URL.
	 */
	public Image getImage(URL url) {
		return Toolkit.getDefaultToolkit().getImage(url);
	} // end getImage

	/**
	 * Finds and returns the applet in the document represented by this
	 * applet context with the given name.	This implementation allways
	 * returns null.
	 *
	 * @param name An applet name.
	 * @return The applet with the given name, or null if not found.
	 */
	public Applet getApplet(String name) {
		return null;
	} // end getApplet

	/**
	 * Finds all the applets in the document represented by this applet
	 * context.  This implementation allways returns an empty enumeration.
	 *
	 * @return An enumeration of all applets in the document.
	 */
	public Enumeration getApplets() {
		return this;
	} // end getApplets

	/**
	 * Replaces the Web page currently being viewed with the given URL.
	 * This method is ignored by this applet context.
	 *
	 * @param url An absolute URL giving the location of the document.
	 */
	public void showDocument(URL url) {
		// do nothing
	} // end showDocument

	/**
	 * Requests that the browser or applet viewer shows a Web page.
	 * This method is ignored by this applet context.
	 *
	 * @param url An absolute URL giving the location of the document.
	 * @param target A String indicating where to display the page.
	 */
	public void showDocument(URL url, String target) {
		// do nothing
	} // end showDocument

	/**
	 * Requests that the argument string be displayed in the status stream.
	 *
	 * @param status A string to write to the status stream.
	 */
	public void showStatus(String status) {
		if (writer != null) {
			writer.println(status);
			writer.flush();
		} // end if
	} // end showStatus

	// --- Enumeration -------------------------------------------------
	/** Tests if this enumeration contains more elements. */
	public boolean hasMoreElements() {
		return false;
	} // end hasMoreElements

	/** Returns the next element of this enumeration. */
	public Object nextElement() {
		throw new NoSuchElementException();
	} // end nextElement

	// --- Observer ----------------------------------------------------
	public void update(Observable o,Object arg) {
		setChanged();
		notifyObservers(arg);
	} // end update

} // end StandaloneContext

/* ******************************************************************
	 end of file
*********************************************************************/
