/* ******************************************************************

   class    : CompileAction
   date     : 27.07.98
   compiler : javac (jdk 1.1.6)

*********************************************************************/

/* ******************************************************************
   import statements
*********************************************************************/

import java.awt.Frame;
import java.awt.Toolkit;
import java.awt.event.ActionEvent;
import java.io.File;
import java.util.Observer;
import java.util.Observable;
import java.util.Hashtable;
import java.util.Enumeration;
import java.util.Properties;

import com.sun.java.swing.AbstractAction;

import Utils.FrameUtil;
import Messages.LockMessage;
import Messages.UnlockMessage;
import Messages.TerminateMessage;

/**
 * Compiles the current editor file.
 *
 * @author puehringer edgar
 */
class CompileAction extends AbstractAction implements Observer {

  // class variable declarations
  private static final String COMPILE_ACTION = "compile";

  // instance variable declarations
  protected Frame frame;
  protected AbstractCompiler compiler;
  protected boolean enabled = true;
  protected boolean active  = true;

  // constructors
  CompileAction(Frame frame, AbstractCompiler compiler) {
    this(COMPILE_ACTION,frame,compiler);
  } // end constructor CompileAction

  CompileAction(String nm, Frame frame, AbstractCompiler compiler) {
    super(nm);
    this.frame    = frame;
    this.compiler = compiler;
    if ((this.frame == null) || (this.compiler == null))
      super.setEnabled(false);
  } // end constructor CompileAction

  // methods
  public void actionPerformed(ActionEvent e) {
    CodepadPanel cpp;
    File[] files;

    cpp = (CodepadPanel)FrameUtil.contains(frame,CodepadPanel.class);
    if (cpp == null) {
      ProjectFilePanel pfp;
      Object[] objects;

      pfp = (ProjectFilePanel)FrameUtil.contains(frame,ProjectFilePanel.class);
      Utils.Assert.assert(Utils.Assert.ENABLED &&
        (pfp != null),"No CodepadPanel or ProjectFilePanel found");
      objects = pfp.getSelectedValues();
      files   = new File[objects.length];
      for (int i=0; i<objects.length; i++) files[i] = (File)objects[i];
    }
    else {
      files    = new File[1];
      files[0] = cpp.getCurrentFile();
    } // end if
    if (files.length == 0) {
      Toolkit.getDefaultToolkit().beep();
    }
    else {
      Hashtable ht = getEditors();

      // the following line handle compiling editor contents that
      // have no name and are saved the first time
      if (files[0] == null) {
        if ((ht == null) || !cpp.saveCurrentFile()) {
          if (ht == null) Toolkit.getDefaultToolkit().beep();
          return;
        } // end if
        files[0] = cpp.getCurrentFile();
      } // end if
      if (ht != null) for (int i=0; i<files.length; i++) {
        cpp = (CodepadPanel)ht.get(files[i].getAbsolutePath());
        if ((cpp != null) && !cpp.saveCurrentFile()) return;
      } // end for end if
      compiler.postMessage(new LockMessage());
      compiler.addObserver(this);
      compiler.compile(files);
    } // end if
  } // end actionPerformed

  /**
   * Sets/tests the enabled state of the Action.  When enabled,
   * any component associated with this object is active and
   * able to fire this object's actionPerformed method.
   */
  public void setEnabled(boolean b) {
    enabled = b;
    super.setEnabled(enabled && active &&
                     (frame != null) &&(compiler != null));
  } // end Enabled

  /**
   * Sets/tests the activation state of the Action.  When active,
   * files must be available for compilation.
   */
  public void setActive(boolean b) {
    active = b;
    super.setEnabled(enabled && active &&
                     (frame != null) &&(compiler != null));
  } // end Enabled

  /** Set the hosting frame of this compiler action. */
  public void setFrame(Frame f) {
    frame = f;
    super.setEnabled(enabled && active &&
                     (frame != null) &&(compiler != null));
  } // end setFrame

  /** Set the compiler invoked by this action. */
  public void setCompiler(AbstractCompiler c) {
    compiler = c;
    super.setEnabled(enabled && active &&
                     (frame != null) &&(compiler != null));
  } // end setCompiler

  /** Return a hashtable with all editors or null if no save on compile. */
  protected Hashtable getEditors() {
    Enumeration enum = ProjectPanel.getFrameManager().getFrames();
    Hashtable ht     = new Hashtable();

    while (enum.hasMoreElements()) {
      Frame frame = (Frame)enum.nextElement();
      Object obj  = FrameUtil.contains(frame,ProjectPanel.class);

      if (obj != null) {
        Properties prop = ((ProjectPanel)obj).getDesktopProperties();

        if (!Boolean.valueOf(prop.getProperty(Const.ASOC_PROP)).booleanValue())
          return null;
        // end if
      }
      else {
        obj = FrameUtil.contains(frame,CodepadPanel.class);
        if (obj != null) {
          File file = ((CodepadPanel)obj).getCurrentFile();

          if (file != null) ht.put(file.getAbsolutePath(),obj);
        } // end if
      } // end if
    } // end while
    return ht;
  } // end getEditors

  /** Save files, that are members of the project, if enabled. */
  protected boolean conditionalSave() {
    Hashtable ht = getEditors();
    Enumeration enum;

    if (ht == null) return true;
    enum = ht.elements();
    while (enum.hasMoreElements()) {
      CodepadPanel cpp = (CodepadPanel)enum.nextElement();

      if (cpp.isProjectMember() && !cpp.saveCurrentFile()) return false;
    } // end while
    return true;
  } // end conditionalSave

  //--------- Observer ----------------------------------------------
  public void update(Observable o, Object arg) {
    if (arg instanceof TerminateMessage) {
      compiler.deleteObserver(this);
      compiler.postMessage(new UnlockMessage());
    } // end if
  } // end update

} // end CompileAction

/* ******************************************************************
   end of file
*********************************************************************/
