/* ******************************************************************

   class    : ComboTextField
   date     : Jn 08 1999

******************************************************************* */

package CustCtrl;

/* ******************************************************************
   import statements
******************************************************************* */

import java.awt.*;
import java.awt.event.*;
import java.util.Vector;
/**
 * The ComboTextField class is a TextField with a browse button.
 *
 * @author puehringer edgar
 */
public class ComboTextField extends Panel implements ActionListener {

  // class variable declarations
  /** The label of the browse button. */
  public final static String BROWSE_TEXT = "^";

  // instance variable declarations
  /** The text field. */
  public TextField text;
  /** The browse button. */
  public Button btn;
  /** The popup menu that displays the choice. */
  protected PopupMenu popup;
  /** A vector that contains the strings of the choice popup. */
  protected Vector vect;

  // constructors
  /** Create a new ComboTextField object. */
  public ComboTextField() {
    super();
    text = new TextField();
    btn  = new Button(BROWSE_TEXT);
    btn.addActionListener(this);
    vect = new Vector();

    GridBagLayout gridbag          = new GridBagLayout();
    GridBagConstraints constraints = new GridBagConstraints();
    setLayout(gridbag);
    constraints.weightx    = 1.0;
    constraints.weighty    = 1.0;
    constraints.gridwidth  = GridBagConstraints.RELATIVE;
    constraints.gridheight = GridBagConstraints.REMAINDER;
    constraints.fill       = GridBagConstraints.HORIZONTAL;
    gridbag.setConstraints(text,constraints);
    add(text);
    constraints.gridwidth  = GridBagConstraints.REMAINDER;
    constraints.fill       = GridBagConstraints.NONE;
    constraints.anchor     = GridBagConstraints.WEST;
    gridbag.setConstraints(btn,constraints);
    add(btn);
  } // end constructor ComboTextField

  /** Create a new ComboTextField object. */
  public ComboTextField(String t) {
    this();
    text.setText(t);
  } // end constructor ComboTextField

  /** Create a new ComboTextField object. */
  public ComboTextField(int columns) {
    this();
    text.setColumns(columns);
  } // end constructor ComboTextField

  /** Create a new ComboTextField object. */
  public ComboTextField(String t, int columns) {
    this();
    text.setText(t);
    text.setColumns(columns);
  } // end constructor ComboTextField

  // class methods
  public static void main(String[] args) {
    Frame frame        = new Frame();
    ComboTextField ctf = new ComboTextField("Hi,there",15);

    ctf.setLabel("v");
    ctf.add("Test1");
    ctf.add("Test2");
    ctf.add("Test3");
    frame.add(ctf);
    frame.pack();
    frame.show();
  } // end main

  // methods
  /**
   * Sets the text that is presented by this text component to be the
   * specified text.
   *
   * @param t The new text.
   */
  public void setText(String t) {
    text.setText(t);
  } // end setText

  /**
   * Gets the text that is presented by this text component.
   */
  public String getText() {
    return text.getText();
  } // end getText

  /**
   * Sets the number of columns in this text field.
   *
   * @param columns The number of columns.
   */
  public void setColumns(int columns) {
    text.setColumns(columns);
  } // end setColumns

  /**
   * Gets the number of columns in this text field.
   *
   * @return The number of columns.
   */
  public int getColumns() {
    return text.getColumns();
  } // end getColumns

  /**
   * Gets the label of this button.
   *
   * @return The button's label, or null if the button has no label.
   */
  public String getLabel() {
    return btn.getLabel();
  } // end getLabel

  /**
   * Sets the button's label to be the specified string.
   *
   * @param label The new label, or null if the button has no label.
   */
  public void setLabel(String label) {
    btn.setLabel(label);
  } // end setLabel

  /**
   * Adds the specified action listener to receive action events from
   * this button.  Action events occur when a user presses or releases
   * the mouse over this button.
   *
   * @param l The action listener.
   */
  public void addActionListener(ActionListener l) {
    btn.addActionListener(l);
  } // end addActionListener

  /**
   * Removes the specified action listener so that it no longer receives
   * action events from this button. Action events occur when a user
   * presses or releases the mouse over this button.
   *
   * @param l The action listener.
   */
  public void removeActionListener(ActionListener l) {
    btn.removeActionListener(l);
  } // end removeActionListener

  /**
   * Sets the command name for the action event fired by this button.
   * By default this action command is set to match the label of the
   * button.
   *
   * @param command A string used to set the button's action command.
   */
  public void setActionCommand(String command) {
    btn.setActionCommand(command);
  } // end setActionCommand

  /**
   * Returns the command name of the action event fired by this button.
   */
  public String getActionCommand() {
    return btn.getActionCommand();
  } // end getActionCommand

  /**
   * Adds an item to the choice popup.
   *
   * @param item The item to be added.
   */
  public void add(String item) {
    vect.addElement(item);
  } // end add

  /**
   * Adds an item to the choice popup.
   *
   * @param item The item to be added.
   */
  public void addItem(String item) {
    add(item);
  } // end addItem

  /**
   * Inserts the item into the choice popup at the specified position.
   *
   * @param item The item to be inserted.
   * @param index The position at which the item should be inserted.
   */
  public void insert(String item, int index) {
    vect.insertElementAt(item,index);
  } // end insert

  /**
   * Remove the first occurrence of item from the choice popup.
   *
   * @param item The item to remove from the choice popup.
   */
  public void remove(String item) {
    vect.removeElement(item);
  } // end remove

  /**
   * Removes an item from the choice popup at the specified position.
   *
   * @param position The position of the item.
   */
  public synchronized void remove(int position) {
    vect.removeElementAt(position);
  } // end remove

  /** Removes all items from the choice popup. */
  public void removeAll() {
    vect.removeAllElements();
  } // end removeAll

  /** Returns the number of items in the choice popup. */
  public int getItemCount() {
    return vect.size();
  } // end getItemCount

  /**
   * Gets the string at the specified index in this Choice popup.
   *
   * @param index The index at which to begin.
   */
  public String getItem(int index) {
    return (String)vect.elementAt(index);
  } // end getItem

  // --- ActionListener ---------------------------------------------
  /** Invoked when an action occurs. */
  public void actionPerformed(ActionEvent e) {
    Object obj = e.getSource();

    if (obj instanceof Button) {
      if (vect.size() > 0) {
        if (popup == null) {
          popup = new PopupMenu();
          add(popup);
        }
        else {
          popup.removeAll();
        } // end if
        for (int i=0; i<vect.size(); i++) {
          MenuItem mi = new MenuItem((String)vect.elementAt(i));

          mi.addActionListener(this);
          popup.add(mi);
        } // end for
        popup.show(text,0,text.getSize().height - 1);
      } // end if
    } else if (obj instanceof MenuItem) {
      setText(((MenuItem)obj).getLabel());
    } // end if
  } // end actionPerformed

} // end ComboTextField

/* ******************************************************************
   end of file
******************************************************************* */
