/* ******************************************************************

   class    : IntTextField
   date     : 09.08.98
   compiler : javac (jdk 1.1.6)

*********************************************************************/

package CustCtrl;

/* ******************************************************************
   import statements
*********************************************************************/

import java.awt.*;
import java.awt.event.KeyListener;
import java.awt.event.KeyEvent;

/**
 *
 * A text field that preferes integer values.
 *
 * @author puehringer edgar
 *
 */
public class IntTextField extends TextField implements KeyListener {

  // instance variable declarations
  /** True if negative values can be typed. */
  protected boolean allowNegativeValues = false;

  // constructors
  /**
   * Constructs a new int text field.
   */
  public IntTextField() {
    super();
    addKeyListener(this);
  } // end constructor IntTextField

  /**
   * Constructs a new int text field initialized with the specified value.
   *
   * @param value The value to be displayed.
   */
  public IntTextField(Integer value) {
    super(value.toString());
    addKeyListener(this);
  } // end constructor IntTextField

  /**
   * Constructs a new empty int text field with the specified number of
   * columns.
   *
   * @param columns The number of columns.
   */
  public IntTextField(int columns) {
    super(columns);
    addKeyListener(this);
  } // end constructor IntTextField

  /**
   * Constructs a new int text field initialized with the specified
   * text to be displayed, and wide enough to hold the specified
   * number of characters.
   *
   * @param value The value to be displayed.
   * @param columns The number of columns.
   */
  public IntTextField(Integer value, int columns) {
    super(value.toString(),columns);
    addKeyListener(this);
  } // end constructor IntTextField

  // class methods
  /** Only for debuging purposes. */
  public static void main(String[] args) {
    Frame frame       = new Frame();
    IntTextField text = new IntTextField();

    text.enableNegativeValues(true);
    frame.add(text);
    frame.pack();
    frame.show();
  } // end main

  // methods
  /**
   * Gets the Integer that is presented by this int text component.
   *
   * @see setInteger
   */
  public Integer getInteger() {
    Integer i;

    try {
      i = new Integer(getText());
    } catch (NumberFormatException e) {
      i = null;
    }
    return i;
  } // end getInteger

  /**
   * Sets the Integer that is presented by this int text component
   * to be the specified Integer.
   *
   * @param i The new Integer.
   * @see getInteger
   */
  public void setInteger(Integer i) {
    setText(i.toString());
  } // end setInteger

  /**
   * Sets the ability to accept negative values on and off.
   *
   * @param enbl True if this component should accept negative values.
   */
  public void enableNegativeValues(boolean enbl) {
    allowNegativeValues = enbl;
  } // end enableNegativeValues

  // --- KeyListener ---------------------------------------
  /**
   * Invoked when a key has been pressed.
   */
  public void keyPressed(KeyEvent e) {
    char key       = e.getKeyChar();
    boolean reject = (key > 31) && (key < 127) &&
                     ((key < '0') || (key > '9'));

    if (reject && allowNegativeValues && (key == '-')) reject = false;
    if (reject) {
      e.consume();
      getToolkit().beep();
    } // end if
  } // end keyPressed

  /**
   * Invoked when a key has been released.
   */
  public void keyReleased(KeyEvent e) {
    // do nothing
  } // end keyReleased

  /**
   * Invoked when a key has been typed.  This event occurs when
   * a key press is followed by a key release.
   */
  public void keyTyped(KeyEvent e) {
    // do nothing
  } // end keyTyped

} // end IntTextField

/* ******************************************************************
   end of file
*********************************************************************/
