/* ******************************************************************

   class    : ErrorDesc
   date     : 28.07.98
   compiler : javac (jdk 1.1.6)

*********************************************************************/

package ErrorParser;

/* ******************************************************************
   import statements
*********************************************************************/

import java.io.File;

/**
 *
 * A class that represents a comiler error.
 *
 * @author puehringer edgar
 *
 */
public class ErrorDesc {

  // class variable declarations
  /** A error without specification of file and line. */
  public static final int SHORT_ERROR   = 0;
  /** A warning without specification of file and line. */
  public static final int SHORT_WARNING = 1;
  /** A error with specification of file and line. */
  public static final int LONG_ERROR    = 2;
  /** A warning with specification of file and line. */
  public static final int LONG_WARNING  = 3;
  /**
   * A command to reset the error list.
   *
   * @deprecated Use the Messages class tree for commands.
   */
  public static final int RESET_LIST = 4;
  /**
   * A command to indikate the end of compilation.
   *
   * @deprecated Use the Messages class tree for commands.
   */
  public static final int COMPILE_END = 5;

  // instance variable declarations
  public int type;
  public String msg;
  public String code;
  public File file;
  public int line;

  // constructors
  /** Create a new ErrorDesc object. */
  public ErrorDesc() {
  } // end constructor ErrorDesc

  // methods
  /** Return true if this is a message with file and line spec. */
  public final boolean hasFileAndLine() {
    return ((type == LONG_ERROR) || (type == LONG_WARNING));
  } // end hasFileAndLine

  /** Return true if this is a warning. */
  public final boolean isWarning() {
    return ((type == LONG_WARNING) || (type == SHORT_WARNING));
  } // end isWarning

  /** Return true if this is an error, not a warning. */
  public final boolean isError() {
    return ((type == LONG_ERROR) || (type == SHORT_ERROR));
  } // end isError

  /**
   * Return true if this error description contains a command.
   *
   * @deprecated Use the Messages class tree for commands.
   */
  public final boolean isCommand() {
    return ((type == RESET_LIST) || (type == COMPILE_END));
  } // end isCommand

} // end ErrorDesc

/* ******************************************************************
   end of file
*********************************************************************/
