/* ******************************************************************

   class    : MakeAction
   date     : 16.08.98
   compiler : javac (jdk 1.1.6)

*********************************************************************/

/* ******************************************************************
   import statements
*********************************************************************/

import java.awt.Frame;
import java.awt.event.ActionEvent;
import java.util.Observable;
import java.util.Hashtable;
import java.util.Enumeration;

import Messages.LockMessage;
import Messages.UnlockMessage;
import Messages.TerminateMessage;

/**
 * Make the current project.  All source files, that have been changed
 * will be compiled.
 *
 * @author puehringer edgar
 */
class MakeAction extends CompileAction {

  // class variable declarations
  private static final String MAKE_ACTION = "make";

  // instance varaible declarations
  protected AbstractLinker linker;

  // constructors
  MakeAction(Frame frame, AbstractCompiler compiler,
             AbstractLinker linker) {
    super(MAKE_ACTION,frame,compiler);
    this.linker = linker;
    setEnabled(this.linker != null);
  } // end constructor MakeAction

  // methods
  public void actionPerformed(ActionEvent e) {
    if (!conditionalSave()) return;
    compiler.postMessage(new LockMessage());
    compiler.addObserver(this);
    compiler.make();
  } // end actionPerformed

  /** Set the linker command invoked by this action. */
  public void setLinker(AbstractLinker l) {
    linker = l;
    super.setEnabled(linker != null);
  } // end setLinker

  public void update(Observable o, Object arg) {
    if (arg instanceof TerminateMessage) {
      if (o instanceof AbstractCompiler) {
        boolean success = ((TerminateMessage)arg).success;

        compiler.deleteObserver(this);
        if (success) {
          linker.addObserver(this);
          linker.link(frame);
        }
        else {
          compiler.postMessage(new UnlockMessage());
        } // end if
      }
      else { // if o instance of AbstractLinker
        linker.deleteObserver(this);
        linker.postMessage(new UnlockMessage());
      } // end if
    } // end if
  } // end update

} // end MakeAction

/* ******************************************************************
   end of file
*********************************************************************/
