/* ******************************************************************

   author     : puehringer edgar

   compiler   : javac (jdk 1.1.6)

   class      : Statusbar
   date       : 19.05.98
   description: a status bar that displays msg, progress bars, etc.

*********************************************************************/

/* ******************************************************************
   import statements
*********************************************************************/

import java.awt.*;

import com.sun.java.swing.*;

/* ******************************************************************
   top level class declaration
*********************************************************************/

public class Statusbar extends JPanel {

  // class variable declarations

  // instance variable declarations
  private JLabel label;
  private JProgressBar progress;
  private boolean showProgress;
  private Component component;

  // constructors
  /**
   * Create a new status bar.
   */
  public Statusbar() {
    this(null);
  } // end constructor Statusbar

  /**
   * Create a new status bar.
   *
   * @param label The status bar's label.
   */
  public Statusbar(String statusText) {
    super(true);
    setLayout(new BorderLayout());
    setBackground(SystemColor.control);
    if (statusText == null) label = new JLabel();
      else label = new JLabel(statusText);
    add("Center",label); 
    progress = new JProgressBar();
    progress.setBackground(SystemColor.control);
    progress.setMinimum(0);
    progress.setMaximum(10);
    progress.setValue(0);
    progress.setBorderPainted(false);
    add("East",progress);
    showProgress = false;
  } // end constructor Statusbar

  // methods
  /**
   * Sets the status bar's label to be the specified string.
   */
  public synchronized void setLabel(String statusText) {
    label.setText(statusText);
    invalidate();
  } // end setLabel

  /**
   * Sets the progress bar's maximum and value.
   */
  public synchronized void setProgress(int cur, int max) {
    if (!showProgress) {
      if (progress.isBorderPainted())
        add("East",progress);
      else
        progress.setBorderPainted(true);
      // end if
      showProgress = true;
      invalidate();
    } // end if
    progress.setMaximum(max);
    progress.setValue(cur);
    repaint();
  } // end setProgress

  /**
   * Sets the progress bar's value.
   */
  public synchronized void setProgress(int cur) {
    progress.setValue(cur);
  } // end setProgress

  /**
   * Remove the progress bar.
   */
  public synchronized void removeProgress() {
    if (showProgress) {
      remove(progress);
      showProgress = false;
      invalidate();
      repaint();
    } // end if
  } // end removeProgress

  /**
   * Sets an auxilary component at the left side of the status bar.
   */
  public synchronized void setAuxComponent(Component comp) {
    if (component != null) removeAuxComponent();
    component = comp;
    add("West",component);
    invalidate();
    repaint();
  } // end setAuxComponent

  /**
   * Remove the auxilary component.
   */
  public synchronized void removeAuxComponent() {
    if (component == null) return;
    remove(component);
    invalidate();
    repaint();
  } // end removeAuxComponent

} // end Statusbar

/* ******************************************************************
   end of file
*********************************************************************/
