/* ******************************************************************

   class    : Assert
   date     : Nov 30 1998
   compiler : javac (1.1.6)

******************************************************************* */

/**
 * A class that acts like the C/C++ assertion macro
 * For a detailed description of this topic look at
 * "http://www.afu.com/javafaq.html" and search for
 * "11.6 How can I write C/C++ style assertions in Java?"
 *
 * @author Puehringer Edgar
 */
public final class Assert {

  // class variable declarations
  public static final boolean ENABLED = true;

  // constructors
  // avoid creating instances of this class
  private Assert() {
  } // end constructor Assert

  // class methods
  public static final void assert(boolean b) {
    if (!b) throw new AssertionException();
  } // end assert

  public static final void assert(boolean b, String s) {
    if (!b) throw new AssertionException(s);
  } // end assert

  public static final void assert(long l) {
    if (l == 0L) throw new AssertionException();
  } // end assert

  public static final void assert(long l, String s) {
    if (l == 0L) throw new AssertionException(s);
  } // end assert

  public static final void assert(Object ref) {
    if (ref == null) throw new AssertionException();
  } // end assert

  public static final void assert(Object ref, String s) {
    if (ref == null) throw new AssertionException(s);
  } // end assert

} // end Assert

/* ******************************************************************
   class declarations
*********************************************************************/

class AssertionException extends Error {

  // constructors
  public AssertionException() {
    super();
  } // end AssertionException

  public AssertionException(String s) {
    super(s);
  } // end AssertionException

} // end AssertionException

/* ******************************************************************
   end of file
*********************************************************************/
