#define COMST "/*"
#define COMEN "*/"
#define COMEOL "//"
#pragma unquote COMST
#pragma unquote COMEN
#pragma unquote COMEOL
#pragma getstring PACKAGE Package
#define ENBL
#pragma getbool ENBL Enable assertions
#define __NAME__ Assert
#define __EXT__ .java
#define __ASSERT__
COMST ******************************************************************

   class    : __NAME__
   date     : __DATE__
#ifdef __COMPILER__
   compiler : __COMPILER__
#endif

******************************************************************* COMEN

#ifdef PACKAGE
package PACKAGE;
  #define __RELPATH__ PACKAGE

#endif
COMST*
 * A class that acts like the C/C++ assertion macro.
 * For a detailed description of this topic look at
 * <A HREF="http://www.afu.com/javafaq.html">
 * http://www.afu.com/javafaq.html</A> and search for
 * "11.6 How can I write C/C++ style assertions in Java?".
 * All <code>assert</code> methods throw an AssertException, if
 * the asserted condition is not true and the "Enable assertions"
 * checkbox was selected while creating the class from the template.
 *
 * @see AssertionException
 * @author Puehringer Edgar
 COMEN
public final class __NAME__ {

  // class variable declarations
#ifdef ENBL
  /** True if assert methods are enabled. */
  public static final boolean ENABLED = true;
#else
  /** True if assert methods are enabled. */
  public static final boolean ENABLED = false;
#endif

  // constructors
  // avoid creating instances of this class
  private __NAME__() {
  } COMEOL end constructor __NAME__

  // class methods
  /**
   * Assert that the boolean condition <code>b</code> is true.
   *
   * @param b The boolean condition to check.
   */
  public static final void assert(boolean b) {
  #ifdef ENBL
    if (!b) throw new AssertionException();
  #else
    // Assertions disabled - do nothing
  #endif
  } // end assert

  /**
   * Assert that the boolean condition <code>b</code> is true.
   *
   * @param b The boolean condition to check.
   * @param s The detail message for the resulting exception.
   */
  public static final void assert(boolean b, String s) {
  #ifdef ENBL
    if (!b) throw new AssertionException(s);
  #else
    // Assertions disabled - do nothing
  #endif
  } // end assert

  /**
   * Assert that the long parameter <code>l</code> is not zero.
   *
   * @param l The long value to check.
   */
  public static final void assert(long l) {
  #ifdef ENBL
    if (l == 0L) throw new AssertionException();
  #else
    // Assertions disabled - do nothing
  #endif
  } // end assert

  /**
   * Assert that the long parameter <code>l</code> is not zero.
   *
   * @param l The long value to check.
   * @param s The detail message for the resulting exception.
   */
  public static final void assert(long l, String s) {
  #ifdef ENBL
    if (l == 0L) throw new AssertionException(s);
  #else
    // Assertions disabled - do nothing
  #endif
  } // end assert

  /**
   * Assert that the object reference <code>l</code> is not
   * <code>null</code>.
   *
   * @param ref The object reference to check.
   */
  public static final void assert(Object ref) {
  #ifdef ENBL
    if (ref == null) throw new AssertionException();
  #else
    // Assertions disabled - do nothing
  #endif
  } // end assert

  /**
   * Assert that the object reference <code>l</code> is not
   * <code>null</code>.
   *
   * @param ref The object reference to check.
   * @param s The detail message for the resulting exception.
   */
  public static final void assert(Object ref, String s) {
  #ifdef ENBL
    if (ref == null) throw new AssertionException(s);
  #else
    // Assertions disabled - do nothing
  #endif
  } // end assert

} COMEOL end __NAME__

/* ******************************************************************
   class declarations
*********************************************************************/

/**
 * Thrown when a condition asserted from an <code>assert</code>
 * method of the <code>Assert</code> is not true.
 *
 * @see Assert
 */
class AssertionException extends Error {

  // constructors
  /** Constructs a <code>AssertionException</code> with no detail message. */
  public AssertionException() {
    super();
  } // end AssertionException

  /**
   * Constructs a <code>ClassFormatError</code> with the specified detail message.
   *
   * @param s The detail message.
   */
  public AssertionException(String s) {
    super(s);
  } // end AssertionException

} // end AssertionException

/* ******************************************************************
   end of file
*********************************************************************/
