#define COMST "/*"
#define COMEN "*/"
#pragma unquote COMST
#pragma unquote COMEN
#pragma getstring PACKAGE Package
#pragma getbool __VERSION1_1 Java 1.1 Code
COMST ******************************************************************

   class      : JToolBarLoader
#define __NAME__ JToolBarLoader
#define __EXT__ .java
   date       : __DATE__
#ifdef __COMPILER__
   compiler : __COMPILER__
#endif

******************************************************************* COMEN

#ifdef PACKAGE
package PACKAGE;
  #define __RELPATH__ PACKAGE

#endif
/* ******************************************************************
   import statements
 *********************************************************************/

import java.awt.*;
import java.awt.event.*;
import java.net.URL;
import java.util.*;
import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeEvent;

#ifdef __VERSION1_1
import com.sun.java.swing.event.*;
import com.sun.java.swing.*;
#else
import javax.swing.event.*;
import javax.swing.*;
#endif

/* ******************************************************************
   top level class declaration
 *********************************************************************/

/**
 * Builds up a Swing toolbar by reading the settings from a resource file.
 * It's intended to use this class for loading toolbar's created with
 * Magic Menu.
 *
 * @author Puehringer Edgar
 */
class JToolBarLoader {

  // class variable declarations
  /**
   * Suffix applied to the key used in resource file
   * lookups for an image.
   */
  public static final String IMAGE_SUFFIX = "Image";

  /**
   * Suffix applied to the key used in resource file
   * lookups for a label.
   */
  public static final String LABEL_SUFFIX = "Label";

  /**
   * Suffix applied to the key used in resource file
   * lookups for an action.
   */
  public static final String ACTION_SUFFIX = "Action";

  /**
   * Suffix applied to the key used in resource file
   * lookups for a tooltip.
   */
  public static final String TOOLTIP_SUFFIX = "Tooltip";

  /** The escape character to identify a mnemonic in a label. */
  public static final char MNEMONIC_ESCAPE = '&';

   /** The distance between separated toolbar components. */
   public static final int STRUT_SIZE = 5;

  // instance variable declarations
  private ResourceBundle resources;
  private Hashtable commands;
  private ActionListener defaultAction;

  // constructors
  /**
   * Create a new JToolBarLoader object.
   *
   * @param resources A resources bundle containing the toolbar settings.
   */
  JToolBarLoader(ResourceBundle resources) {
     this.resources = resources;
     commands       = null;
     defaultAction  = null;
  } // end constructor JToolBarLoader

  // class methods
  /** Filters the mnemonic identifiers out of a label string. */
  private static String filterMnemonic(String label, char[] ch) {
    int index = label.indexOf(MNEMONIC_ESCAPE);

    if (index < 0) return label;
    if ((index + 1) < label.length()) {
      char c = label.charAt(index + 1);

      if (c != MNEMONIC_ESCAPE) ch[0] = c;
      return label.substring(0,index) + c +
        filterMnemonic(label.substring(index + 2),ch);
    }
    else {
      return label.substring(0,index);
    } // end if
  } // end filterMnemonic

  // methods
  /**
   * Returns a hashtable containing the toolbar commands.  The hashtable
   * contains pairs of action name and Action object.
   */
  public Hashtable getCommands() {
    return commands;
  } // end getCommands

  /**
   * Set the hashtable containing the toolbar commands.  This hashtable should
   * contain pairs of action name and Action object. If a commands hashtable
   * is set, this should be done before the first call to createToolBar,
   * createTool or createMenuItem.
   *
   * @see #createToolBar
   * @see #createTool
   * @see #createToolBarButton
   */
  public void setCommands(Hashtable commands) {
    this.commands = commands;
  } // end setCommands

  /**
   * Return the default action listener.  This action listener is registered
   * at every toolbar item, which has no associated command in the commands
   * hashtable.
   */
  public ActionListener getDefaultActionListener() {
    return defaultAction;
  } // end getDefaultActionListener

  /**
   * Set the default action listener.  This action listener is registered at
   * every toolbar item,which has no associated command in the commands
   * hashtable. If a ActionListener is set, this should be done before the
   * first call to createToolBar, createTool or createMenuToolBarButton.
   *
   * @see #createToolBar
   * @see #createTool
   * @see #createToolBarButton
   */
  public void setDefaultActionListener(ActionListener al) {
    defaultAction = al;
  } // end setDefaultActionListener

  /**
   * Create a button to go inside of the toolbar.  By default this
   * will load an image resource.
   *
   * @param key The key in the resource file to serve as the basis
   *            of lookups.
   */
  protected JButton createToolBarButton(String key) {
    URL url     = getResource(key + IMAGE_SUFFIX);
    String astr = getResourceString(key + ACTION_SUFFIX);
    String tip  = getResourceString(key + TOOLTIP_SUFFIX);
    JButton b;

    if (url == null) {
      String label = getResourceString(key + LABEL_SUFFIX);

      if (label == null) {
        reportError("Image and label property for toolbar button key \"" +
                  key + "\" not found");
        return null;
      }
      else {
        char[] mnemonic = new char[1];

        mnemonic[0] = (char)0;
        b           = new JButton(filterMnemonic(label,mnemonic)) {

          public float getAlignmentY() {
            return 0.5f;
          } // end getAlignmentY

        };
        if (mnemonic[0] != (char)0)
          b.setMnemonic(mnemonic[0]);
        // end if
      } // end if
    }
    else {
      b = new JButton(loadImageIcon(url)) {

        public float getAlignmentY() {
          return 0.5f;
        } // end getAlignmentY

      };
    } // end if
    b.setRequestFocusEnabled(false);
    b.setMargin(new Insets(1,1,1,1));
    if(tip != null) b.setToolTipText(tip);
    if(astr == null) astr = key;
    b.setActionCommand(astr);

    ActionListener a = getAction(astr);

    if(a != null) {
      b.addActionListener(a);
      if(a instanceof Action) {
        Action action = (Action)a;

        action.addPropertyChangeListener(new ActionChangedListener(b));
        b.setEnabled(action.isEnabled());
      } // end if
    }
    else {
      b.setEnabled(false);
    } // end if
    return b;
  } // end createToolBarButton

  /**
   * Return the Action with name cmd stored in the command hashtable.
   * If it doesn't exist, return the default action listener.
   *
   * @param cmd The action command of the associated toolbar button.
   */
  protected ActionListener getAction(String cmd) {
    ActionListener a;

    if(commands == null) a = null;
      else a = (ActionListener)commands.get(cmd);
    if(a == null) return defaultAction;
      else return a;
  } // end getAction

  /**
   * Read a string from the resource file containing the toolbar
   * definition.
   */
  protected String getResourceString(String key) {
    String str;

    try {
      str = resources.getString(key);
    } catch (MissingResourceException mre) {
      str = null;
    }
    return str;
  } // end getResourceString

  /**
   * Read the name of an image from the resource bundle and convert
   * if to an URL.  The name in the resource bundle must be a relative
   * path. It's relative to the location of this class.
   */
  protected URL getResource(String key) {
    String name = getResourceString(key);
    URL url;

    if(name == null) return null;
    url = this.getClass().getResource(name);
    return url;
  } // end getResource

  /**
   * Take the given string and chop it up into a series
   * of strings on whitespace boundries. This is useful
   * for trying to get an array of strings out of the
   * resource file.
   */
  protected String[] tokenize(String input) {
    Vector v = new Vector();
    StringTokenizer t = new StringTokenizer(input);
    String cmd[];

    while(t.hasMoreTokens()) v.addElement(t.nextToken());
    cmd = new String[v.size()];
    for(int i = 0;i < cmd.length;i++)
      cmd[i] = (String)v.elementAt(i);
    // end for
    return cmd;
  } // end tokenize

  /**
   * Create the toolbar for the specified key.  This pulls the
   * definition of the toolbar from the associated resource bundle.
   */
  protected JToolBar createToolBar(String key) {
    JToolBar tb = new JToolBar();
    String tbDesc = getResourceString(key);
    String[] toolKeys;

    if (tbDesc == null) {
      reportError("ToolBar \"" + key + "\" not found or empty");
      return null;
    } // end if
    toolKeys = tokenize(tbDesc);
    for (int i=0; i<toolKeys.length; i++) {
      if(toolKeys[i].equals("-")) {
        tb.add(Box.createHorizontalStrut(STRUT_SIZE));
      }
      else {
        Component comp = createTool(toolKeys[i]);

        if (comp != null) tb.add(comp);
      } // end if
    } // end for
    tb.add(Box.createHorizontalGlue());
    tb.setBackground(SystemColor.control);
    return tb;
  } // end createToolBar

  /**
   * Hook through which every toolbar item is created.  This method
   * can be used to integrate custom gui elements into the toolbar.
   */
  protected Component createTool(String key) {
    return createToolBarButton(key);
  } // end createTool

  /**
   * Hook through which ImageIcons are loaded.  If some kind of
   * image cache should be implemented, this method can be
   * overwritten.
   */
  protected ImageIcon loadImageIcon(URL url) {
    return new ImageIcon(url);
  } // end loadImageIcon

  /**
   * This method will be called, if some errors occur.  By default this
   * will cause an output to stderr.
   */
  protected void reportError(String text) {
    System.err.println("JToolBarLoader: " + text + ".");
  } // end reportError

  // inner classes
  private class ActionChangedListener implements PropertyChangeListener {

    // class variable declarations
    JButton button;

    // constructors
    ActionChangedListener(JButton b) {
      super();
      button = b;
    } // end constructor ActionChangedListener

    // methods
    public void propertyChange(PropertyChangeEvent e) {
      String propertyName = e.getPropertyName();

      if(e.getPropertyName().equals(Action.NAME)) {
        String text = (String)e.getNewValue();

        button.setText(text);
      } else if(propertyName.equals("enabled")) {
        Boolean enabledState = (Boolean)e.getNewValue();

        button.setEnabled(enabledState.booleanValue());
      } // end if
    } // end propertyCange

  } // end ActionChangedListener

} // end JToolBarLoader

/* ******************************************************************
   end of file
 *********************************************************************/
